@@ -381,7 +381,7 @@ class VariableOsDeviceName(ReadonlyVariable):
                 return ("%s %s" %
                         (vendor, model)).strip()
             else:
-                for k, v in self.nameless_devires.items():
+                for k, v in self.nameless_devices.items():
                     if k in devicepath:
                         return v
             return ""
